import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import { IconUser } from '../icons/icon-user/icon-user';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import { RouteLink } from '../route-link/route-link';
import './profile-menu.scss';

export class ProfileMenu extends Component {
  static propTypes = {
    isUserLoggedIn: PropTypes.bool.isRequired,
  };

  state = {
    menuOpen: false,
  }

  toggleMenu = () => {
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  }

  render() {
    const { menuOpen } = this.state;
    const { isUserLoggedIn } = this.props;

    return (
      <Dropdown isOpen={menuOpen} toggle={this.toggleMenu}>
        <DropdownToggle nav className="px-0">
          <div className="profile-menu d-flex">
            <div className="pr-1">
              <IconUser />
            </div>
            <div>
              <IconArrowDown />
            </div>
          </div>
        </DropdownToggle>
        <DropdownMenu right>
          {!isUserLoggedIn ?
            <Fragment>
              <DropdownItem tag={RouteLink} to="/sign-in/">
                <FormattedMessage id="menu.sign-in.text" />
              </DropdownItem>
              <DropdownItem tag={RouteLink} to="/sign-up/">
                <FormattedMessage id="menu.registration.text" />
              </DropdownItem>
            </Fragment> :
            <DropdownItem tag={RouteLink} to="/sign-out/">
              <FormattedMessage id="menu.sign-out.text" />
            </DropdownItem>
          }
        </DropdownMenu>
      </Dropdown>
    );
  }
}
