import store from 'store';
import { LOCALES, LOCALE, DEFAULT_LOCALE, LOCALE_KEYS } from '../constants';

export const lang2LocaleMapping = {
  en: LOCALE_KEYS.EN_US,
  zh: LOCALE_KEYS.ZH_CN,
  ru: LOCALE_KEYS.RU_RU,
  ko: LOCALE_KEYS.KO_KO,
};

export const locale2LangMapping = {
  [LOCALE_KEYS.EN_US]: 'en',
  [LOCALE_KEYS.ZH_CN]: 'zh',
  [LOCALE_KEYS.RU_RU]: 'ru',
  [LOCALE_KEYS.KO_KO]: 'ko',
};

export const locale2LangSecondMapping = {
  [LOCALE_KEYS.EN_US]: 'en',
  [LOCALE_KEYS.ZH_CN]: 'cn',
  [LOCALE_KEYS.RU_RU]: 'ru',
  [LOCALE_KEYS.KO_KO]: 'ko',
};

export const chooseLang = (locale) => {
  const langStore = store.get(LOCALE);
  const getlocale = lang2LocaleMapping[locale] || lang2LocaleMapping[langStore];
  if (LOCALES.includes(getlocale)) {
    return locale2LangMapping[getlocale];
  }
  return locale2LangMapping[DEFAULT_LOCALE];
};

export const chooseLangSecond = (locale) => {
  const langStore = store.get(LOCALE);
  const getlocale = lang2LocaleMapping[locale] || lang2LocaleMapping[langStore];
  if (LOCALES.includes(getlocale)) {
    return locale2LangSecondMapping[getlocale];
  }
  return locale2LangSecondMapping[DEFAULT_LOCALE];
};

export const chooseLocale = () => {
  const locale = store.get(LOCALE);

  if (typeof lang2LocaleMapping[locale] !== 'undefined') {
    return lang2LocaleMapping[locale];
  }
  return DEFAULT_LOCALE;
};

export const wrapRoute2Locale = (route, locale = '') => `/${locale || chooseLocale()}${route}`;
